@@ -1,38 +1,33 @@
 package Mojolicious::Plugin::GzipStatic;
 use Mojo::Base 'Mojolicious::Plugin';
-use Mojo::Util qw(monkey_patch);
 use IO::Compress::Gzip 'gzip';
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 sub register {
     my ($self, $app) = @_;
 
-    monkey_patch 'Mojolicious::Static', serve => sub {
-        my ($self, $c, $rel) = @_;
+    $app->hook(after_static => sub {
+        my $c = shift;
 
-        return undef unless my $asset = $self->file($rel);
-        my $headers = $c->res->headers;
-
-        my $types = $c->app->types;
-        my $type = $rel =~ /\.(\w+)$/ ? $types->type($1) : undef;
+        my $type = $c->res->headers->content_type;
         if (defined($type)
             && $type =~ /text|xml|javascript|json/
             && ($c->req->headers->accept_encoding // '') =~ /gzip/i) {
             $c->res->headers->append(Vary => 'Accept-Encoding');
 
             $c->res->headers->content_encoding('gzip');
+
+            my $asset = $c->res->content->asset;
+
             gzip \$asset->slurp, \my $compressed;
+
             $asset = Mojo::Asset::Memory->new;
             $asset->add_chunk($compressed);
+
+            $c->res->content->asset($asset);
         }
-
-        return !!$self->serve_asset($c, $asset) if $headers->content_type;
-
-        # Content-Type
-        $headers->content_type($type || $types->type('txt'));
-        return !!$self->serve_asset($c, $asset);
-    };
+    });
 }
 
 1;
@@ -42,7 +37,7 @@ __END__
 
 =head1 NAME
 
-Mojolicious::Plugin::GzipStatic - Mojolicious Plugin to to compress the static files before serving them.
+Mojolicious::Plugin::GzipStatic - Mojolicious Plugin to compress the static files before serving them.
 
 =head1 SYNOPSIS
 
@@ -54,8 +49,7 @@ Mojolicious::Plugin::GzipStatic - Mojolicious Plugin to to compress the static f
 
 =head1 DESCRIPTION
 
-L<Mojolicious::Plugin::GzipStatic> is a L<Mojolicious> plugin that monkey_patches 
-L<Mojolicious::Static> to compress the static files before serving them.
+L<Mojolicious::Plugin::GzipStatic> is a L<Mojolicious> plugin to compress the static files before serving them.
 
 See L<https://en.wikipedia.org/wiki/HTTP_compression> and
 L<http://mojolicious.org/perldoc/Mojolicious/Guides/Rendering#Post-processing-dynamic-content>.
